@@ -21,9 +21,11 @@ def grimoire(ctx, c):
 
 
 @grimoire.command(help="Run the command")
-@click.option("--c", "-command", help="Command to run. If not insert launch all the commands")
+@click.option(
+    "--c", "-command", help="Command to run. If not insert launch all the commands"
+)
 @click.option("--u", "-url", help="On which url launch the command")
-@click.option('--stats/--no-stats', default=False, help="Launch stats after the run")
+@click.option("--stats/--no-stats", default=False, help="Launch stats after the run")
 @click.pass_context
 def run(ctx, c, u, stats):
     ctx.obj.run(c, u)
@@ -43,9 +45,7 @@ def stats(ctx, c, u):
 
 @grimoire.command(help="Show the info")
 @click.option("--u", "-url", help="On which url return the info")
-@click.option(
-    "--c", "-command", help="On which directive return the info"
-)
+@click.option("--c", "-command", help="On which directive return the info")
 @click.pass_context
 def info(ctx, c, u):
     ctx.obj.info(command=c, url=u)
@@ -61,8 +61,8 @@ def add(ctx, u):
 @grimoire.command(help="Remove the url to the command check")
 @click.option("--u", "-url", help="Url to remove")
 @click.pass_context
-def remove(ctx, c, u):
-    ctx.obj.remove(c, u)
+def remove(ctx,  u):
+    ctx.obj.remove( u)
 
 
 @grimoire.command(help="Show the hello message")
