@@ -58,11 +58,23 @@ class SSLVerify(Plugin):
             if will_expire_in is None:
                 output_strng = broken_response(url)
             elif will_expire_in < limit:
-                output_strng = {"status": "KO", "expired": str(will_expire_in), "domain": url}
+                output_strng = {
+                    "status": "KO",
+                    "expired": str(will_expire_in),
+                    "domain": url,
+                }
             elif will_expire_in < limit:
-                output_strng = {"status": "XX", "expired": str(will_expire_in), "domain": url}
+                output_strng = {
+                    "status": "XX",
+                    "expired": str(will_expire_in),
+                    "domain": url,
+                }
             else:
-                output_strng = {"status": "OK", "expired": str(will_expire_in), "domain": url}
+                output_strng = {
+                    "status": "OK",
+                    "expired": str(will_expire_in),
+                    "domain": url,
+                }
         self.l.info(f"{directive} return {output_strng}")
         return output_strng
 
@@ -72,8 +84,12 @@ class SSLVerify(Plugin):
             stat[data[directive]["status"]] = 1
             other = {}
             if data[directive]["status"] != "OK":
-                other = {colored(data[directive]["domain"],"red"): colored(data[directive]['expired'], "red")}
+                other = {
+                    colored(data[directive]["domain"], "red"): colored(
+                        data[directive]["expired"], "red"
+                    )
+                }
             return stat, other
         except KeyError as e:
             self.l.error(str(e))
-            return {}, {}
\ No newline at end of file
+            return {}, {}
